@@ -53,15 +53,19 @@ while locale_setup_list:
     LOCALE_LIST.append(key)
     LOCALE_DICT[key] = value
 
-# Some icons are different at Christmas
+# Some icons are different at Christmas/on national holidays
 today = datetime.date.today()
 day = today.strftime("%d")
 month = today.strftime("%m")
+
+xmas_flag = False
+eesti_flag = False
 if (int(month) == 12 and int(day) >= 24) \
 or (int(month) == 1 and int(day) <= 5):
     xmas_flag = True
-else:
-    xmas_flag = False
+elif (int(month) == 2 and int(day) == 24) \
+or (int(month) == 8 and int(day) == 20):
+    eesti_flag = True
 
 # Standard list and dictionaries
 time_metric_setup_list = [
@@ -166,6 +170,31 @@ while file_output_setup_list:
     FILE_OUTPUT_NAME_DICT[key] = value
     FILE_OUTPUT_CONVERT_DICT[key] = value2
 
+YTDLP_OUTPUT_TYPE_LIST = [
+    'subtitle',
+    'thumbnail',
+    'description',
+    'annotation',
+    'infojson',
+    'pl_thumbnail',
+    'pl_description',
+    'pl_infojson',
+    'chapter',
+]
+
+SPONSORBLOCK_CATEGORY_LIST = [
+    'sponsor',
+    'selfpromo',
+    'interaction',
+    'intro',
+    'outro',
+    'preview',
+    'music_offtopic',
+]
+SPONSORBLOCK_ACTION_LIST = [
+    'skip',
+]
+
 video_option_setup_list = [
     # List of YouTube extractor (format) codes, based on the original list in
     #   youtube-dl-gui, and supplemented by this list:
@@ -588,34 +617,21 @@ while language_setup_list:
     LANGUAGE_CODE_LIST.append(key)
     LANGUAGE_CODE_DICT[key] = value
 
-if not xmas_flag:
-    DIALOGUE_ICON_DICT = {
-        'newbie_icon': 'newbie_icon_64.png',
-        'ready_icon': 'ready_icon_64.png',
-        'system_icon': 'system_icon_64.png',
-    }
-else:
-    DIALOGUE_ICON_DICT = {
-        'newbie_icon': 'newbie_icon_64.png',
-        'ready_icon': 'ready_icon_64.png',
-        'system_icon': 'system_icon_xmas_64.png',
-    }
+DIALOGUE_ICON_DICT = {
+    'newbie_icon': 'newbie_icon_64.png',
+    'ready_icon': 'ready_icon_64.png',
+    'system_icon': 'system_icon_64.png',
+    'yt_remind_icon_en': 'yt_remind_icon_en.png',
+    'yt_remind_icon_kr': 'yt_remind_icon_kr.png',
+    'yt_remind_icon_nl': 'yt_remind_icon_nl.png',
+}
+if xmas_flag:
+    DIALOGUE_ICON_DICT['system_icon'] = 'system_icon_xmas_64.png'
+elif eesti_flag:
+    DIALOGUE_ICON_DICT['system_icon'] = 'system_icon_eesti_64.png'
 
-if not xmas_flag:
-    STATUS_ICON_DICT = {
-        'default_icon': 'status_default_icon_64.png',
-        'check_icon': 'status_check_icon_64.png',
-        'check_live_icon': 'status_check_live_icon_64.png',
-        'download_icon': 'status_download_icon_64.png',
-        'download_live_icon': 'status_download_live_icon_64.png',
-        'update_icon': 'status_update_icon_64.png',
-        'refresh_icon': 'status_refresh_icon_64.png',
-        'info_icon': 'status_info_icon_64.png',
-        'tidy_icon': 'status_tidy_icon_64.png',
-        'livestream_icon': 'status_livestream_icon_64.png',
-        'process_icon': 'status_process_icon_64.png',
-    }
-else:
+
+if xmas_flag:
     STATUS_ICON_DICT = {
         'default_icon': 'status_default_icon_xmas_64.png',
         'check_icon': 'status_check_icon_xmas_64.png',
@@ -629,6 +645,34 @@ else:
         'livestream_icon': 'status_livestream_icon_xmas_64.png',
         'process_icon': 'status_process_icon_xmas_64.png',
     }
+elif eesti_flag:
+    STATUS_ICON_DICT = {
+        'default_icon': 'status_default_icon_eesti_64.png',
+        'check_icon': 'status_check_icon_eesti_64.png',
+        'check_live_icon': 'status_check_live_icon_eesti_64.png',
+        'download_icon': 'status_download_icon_eesti_64.png',
+        'download_live_icon': 'status_download_live_icon_eesti_64.png',
+        'update_icon': 'status_update_icon_eesti_64.png',
+        'refresh_icon': 'status_refresh_icon_eesti_64.png',
+        'info_icon': 'status_info_icon_eesti_64.png',
+        'tidy_icon': 'status_tidy_icon_eesti_64.png',
+        'livestream_icon': 'status_livestream_icon_eesti_64.png',
+        'process_icon': 'status_process_icon_eesti_64.png',
+    }
+else:
+    STATUS_ICON_DICT = {
+        'default_icon': 'status_default_icon_64.png',
+        'check_icon': 'status_check_icon_64.png',
+        'check_live_icon': 'status_check_live_icon_64.png',
+        'download_icon': 'status_download_icon_64.png',
+        'download_live_icon': 'status_download_live_icon_64.png',
+        'update_icon': 'status_update_icon_64.png',
+        'refresh_icon': 'status_refresh_icon_64.png',
+        'info_icon': 'status_info_icon_64.png',
+        'tidy_icon': 'status_tidy_icon_64.png',
+        'livestream_icon': 'status_livestream_icon_64.png',
+        'process_icon': 'status_process_icon_64.png',
+    }
 
 TOOLBAR_ICON_DICT = {
     'tool_channel_large': 'channel_large.png',
@@ -719,6 +763,7 @@ SMALL_ICON_DICT = {
     'dl_options_small': 'dl_options.png',
     'download_small': 'download.png',
     'error_small': 'error.png',
+    'external_small': 'external.png',
     'folder_black_small': 'folder_black.png',
     'folder_blue_small': 'folder_blue.png',
     'folder_green_small': 'folder_green.png',
@@ -727,8 +772,12 @@ SMALL_ICON_DICT = {
     'live_now_small': 'live_now.png',
     'live_wait_small': 'live_wait.png',
     'no_file_small': 'no_file.png',
+    'split_file_small': 'split_file.png',
+    'sponsorblock_small': 'sponsorblock.png',
     'system_error_small': 'system_error.png',
     'system_warning_small': 'system_warning.png',
+    'timestamp_small': 'timestamp.png',
+    'unavailable_small': 'unavailable.png',
     'warning_small': 'warning.png',
 }
 
@@ -756,6 +805,12 @@ THUMB_ICON_DICT = {
     'thumb_both_medium': 'thumb_both_medium.png',
     'thumb_both_large': 'thumb_both_large.png',
     'thumb_both_enormous': 'thumb_both_enormous.png',
+
+    'thumb_default_tiny': 'thumb_default_tiny.png',
+    'thumb_default_small': 'thumb_default_small.png',
+    'thumb_default_medium': 'thumb_default_medium.png',
+    'thumb_default_large': 'thumb_default_large.png',
+    'thumb_default_enormous': 'thumb_default_enormous.png',
 }
 
 EXTERNAL_ICON_DICT = {
@@ -768,6 +823,7 @@ STOCK_ICON_DICT = {
     'stock_cancel': 'cancel_small.png',
     'stock_delete': 'delete_small.png',
     'stock_execute': 'ffmpeg_small.png',
+    'stock_file': 'file_small.png',
     'stock_find': 'find_small.png',
     'stock_go_back': 'go_back_small.png',
     'stock_go_down': 'go_down_small.png',
@@ -787,18 +843,7 @@ STOCK_ICON_DICT = {
     'stock_spell_check': 'spell_check_small.png',
 }
 
-if not xmas_flag:
-    WIN_ICON_LIST = [
-        'system_icon_16.png',
-        'system_icon_24.png',
-        'system_icon_32.png',
-        'system_icon_48.png',
-        'system_icon_64.png',
-        'system_icon_128.png',
-        'system_icon_256.png',
-        'system_icon_512.png',
-    ]
-else:
+if xmas_flag:
     WIN_ICON_LIST = [
         'system_icon_xmas_16.png',
         'system_icon_xmas_24.png',
@@ -809,7 +854,28 @@ else:
         'system_icon_xmas_256.png',
         'system_icon_xmas_512.png',
     ]
-
+elif eesti_flag:
+    WIN_ICON_LIST = [
+        'system_icon_eesti_16.png',
+        'system_icon_eesti_24.png',
+        'system_icon_eesti_32.png',
+        'system_icon_eesti_48.png',
+        'system_icon_eesti_64.png',
+        'system_icon_eesti_128.png',
+        'system_icon_eesti_256.png',
+        'system_icon_eesti_512.png',
+    ]
+else:
+    WIN_ICON_LIST = [
+        'system_icon_16.png',
+        'system_icon_24.png',
+        'system_icon_32.png',
+        'system_icon_48.png',
+        'system_icon_64.png',
+        'system_icon_128.png',
+        'system_icon_256.png',
+        'system_icon_512.png',
+    ]
 
 def do_translate(config_flag=False):
 
@@ -828,15 +894,16 @@ def do_translate(config_flag=False):
     global FOLDER_ALL_VIDEOS, FOLDER_BOOKMARKS, FOLDER_FAVOURITE_VIDEOS, \
     FOLDER_LIVESTREAMS, FOLDER_MISSING_VIDEOS, FOLDER_NEW_VIDEOS, \
     FOLDER_RECENT_VIDEOS, FOLDER_WAITING_VIDEOS, FOLDER_TEMPORARY_VIDEOS, \
-    FOLDER_UNSORTED_VIDEOS
+    FOLDER_UNSORTED_VIDEOS, FOLDER_VIDEO_CLIPS
 
     global YTDL_UPDATE_DICT
 
     global MAIN_STAGE_QUEUED, MAIN_STAGE_ACTIVE, MAIN_STAGE_PAUSED, \
     MAIN_STAGE_COMPLETED, MAIN_STAGE_ERROR, MAIN_STAGET_STALLED, \
     ACTIVE_STAGE_PRE_PROCESS, ACTIVE_STAGE_DOWNLOAD, \
-    ACTIVE_STAGE_POST_PROCESS, ACTIVE_STAGE_CAPTURE, ACTIVE_STAGE_MERGE, \
-    ACTIVE_STAGE_CHECKING, COMPLETED_STAGE_FINISHED, COMPLETED_STAGE_WARNING, \
+    ACTIVE_STAGE_CONCATENATE, ACTIVE_STAGE_POST_PROCESS, \
+    ACTIVE_STAGE_CAPTURE, ACTIVE_STAGE_MERGE, ACTIVE_STAGE_CHECKING, \
+    COMPLETED_STAGE_FINISHED, COMPLETED_STAGE_WARNING, \
     COMPLETED_STAGE_ALREADY, ERROR_STAGE_ERROR, ERROR_STAGE_STOPPED, \
     ERROR_STAGE_ABORT
 
@@ -857,6 +924,7 @@ def do_translate(config_flag=False):
     FOLDER_WAITING_VIDEOS = _('Waiting Videos')
     FOLDER_TEMPORARY_VIDEOS = _('Temporary Videos')
     FOLDER_UNSORTED_VIDEOS = _('Unsorted Videos')
+    FOLDER_VIDEO_CLIPS = _('Video Clips')
 
     # youtube-dl update shell commands
     YTDL_UPDATE_DICT = {
@@ -868,10 +936,14 @@ def do_translate(config_flag=False):
             _('Update using custom youtube-dl path'),
         'ytdl_update_pip':
             _('Update using pip'),
+        'ytdl_update_pip_no_dependencies':
+            _('Update using pip (use --no-dependencies option)'),
         'ytdl_update_pip_omit_user':
             _('Update using pip (omit --user option)'),
         'ytdl_update_pip3':
             _('Update using pip3'),
+        'ytdl_update_pip3_no_dependencies':
+            _('Update using pip3 (use --no-dependencies option)'),
         'ytdl_update_pip3_omit_user':
             _('Update using pip3 (omit --user option)'),
         'ytdl_update_pip3_recommend':
@@ -880,8 +952,12 @@ def do_translate(config_flag=False):
             _('Update using PyPI youtube-dl path'),
         'ytdl_update_win_32':
             _('Windows 32-bit update (recommended)'),
+        'ytdl_update_win_32_no_dependencies':
+            _('Windows 32-bit update (use --no-dependencies option)'),
         'ytdl_update_win_64':
             _('Windows 64-bit update (recommended)'),
+        'ytdl_update_win_64_no_dependencies':
+            _('Windows 64-bit update (use --no-dependencies option)'),
         'ytdl_update_disabled':
             _('youtube-dl updates are disabled'),
     }
@@ -896,6 +972,7 @@ def do_translate(config_flag=False):
     # Sub-stages of the 'Active' stage
     ACTIVE_STAGE_PRE_PROCESS = _('Pre-processing')
     ACTIVE_STAGE_DOWNLOAD = _('Downloading')
+    ACTIVE_STAGE_CONCATENATE = _('Concatenating')
     ACTIVE_STAGE_POST_PROCESS = _('Post-processing')
     ACTIVE_STAGE_CAPTURE = _('Capturing')               # Used by YTSC
     ACTIVE_STAGE_MERGE = _('Merging')                   # Used by YTSC
